"use client";

import { Menu, X } from "lucide-react";
import Image from "next/image";
import { useEffect, useState } from "react";
import Link from "next/link";
const navigation = [
  { name: "Home", href: "/" },
  { name: "About", href: "#about" },
  { name: "Program", href: "#program" },
  { name: "Speakers", href: "#speakers" },
  { name: "Call for Papers", href: "#call-for-papers" },
  { name: "Conference Theme", href: "#conference-theme" },
  { name: "Registration", href: "#registration-fee" },
  { name: "Submission", href: "#submission" },
  { name: "Publications", href: "#publications" },
];

const Navbar = () => {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const [activeSection, setActiveSection] = useState<string>("");
  const [isMounted, setIsMounted] = useState(false);

  useEffect(() => {
    setIsMounted(true);
  }, []);

  useEffect(() => {
    if (!isMounted) return;

    const observer = new IntersectionObserver(
      (entries) => {
        entries.forEach((entry) => {
          if (entry.isIntersecting) {
            setActiveSection(entry.target.id ? `#${entry.target.id}` : "/");
          }
        });
      },
      {
        rootMargin: "-80px 0px -50% 0px",
      }
    );

    // Observe the banner section for home
    const homeSection = document.querySelector("main > :first-child");
    if (homeSection) {
      observer.observe(homeSection);
    }

    // Observe all other sections
    navigation.forEach((item) => {
      if (item.href !== "/") {
        const element = document.querySelector(item.href);
        if (element) {
          observer.observe(element);
        }
      }
    });

    return () => observer.disconnect();
  }, [isMounted]);

  const handleClick = (
    e: React.MouseEvent<HTMLAnchorElement>,
    href: string
  ) => {
    e.preventDefault();

    if (href === "/") {
      window.scrollTo({ top: 0, behavior: "smooth" });
      setActiveSection("/");
    } else {
      const element = document.querySelector(href);
      if (element) {
        const headerOffset = 80;
        const elementPosition = element.getBoundingClientRect().top;
        const offsetPosition =
          elementPosition + window.pageYOffset - headerOffset;

        window.scrollTo({
          top: offsetPosition,
          behavior: "smooth",
        });
        setActiveSection(href);
      }
    }

    setMobileMenuOpen(false);
  };

  const getNavItemClass = (href: string) => {
    if (!isMounted) return "text-gray-900";
    return `whitespace-nowrap text-sm font-semibold leading-6 hover:text-primary transition-colors ${
      activeSection === href ? "text-primary" : "text-gray-900"
    }`;
  };

  const getMobileNavItemClass = (href: string) => {
    if (!isMounted) return "text-gray-900";
    return `-mx-3 block rounded-lg px-3 py-2 text-base font-semibold leading-7 hover:bg-gray-50 ${
      activeSection === href ? "text-primary" : "text-gray-900"
    }`;
  };

  return (
    <header className="fixed inset-x-0 top-0 z-50 bg-white/80 backdrop-blur-md">
      <nav
        className="flex items-center justify-between py-4 max-w-[1440px] mx-auto"
        aria-label="Global"
      >
        {/* Left Logo */}
        <div className="flex lg:flex-none px-4">
          <Link
            href="/"
            className="-m-1.5 p-1.5"
            onClick={(e) => handleClick(e, "/")}
          >
            <span className="sr-only">NACTE</span>
            <Image
              className="h-16 w-auto"
              src="/logos/nacte.jpeg"
              alt="NACTE Logo"
              width={64}
              height={64}
            />
          </Link>
        </div>

        {/* Mobile menu button */}
        <div className="flex lg:hidden">
          <button
            type="button"
            className="-m-2.5 inline-flex items-center justify-center rounded-md p-2.5 text-gray-700"
            onClick={() => setMobileMenuOpen(true)}
          >
            <span className="sr-only">Open main menu</span>
            <Menu className="h-6 w-6" aria-hidden="true" />
          </button>
        </div>

        {/* Center Navigation */}
        <div className="hidden lg:flex lg:gap-x-8 lg:flex-1 lg:justify-center max-w-4xl">
          {navigation.map((item) => (
            <a
              key={item.name}
              href={item.href}
              onClick={(e) => handleClick(e, item.href)}
              className={getNavItemClass(item.href)}
            >
              {item.name}
            </a>
          ))}
        </div>

        {/* Right Logo */}
        <div className="hidden lg:flex lg:flex-none px-4">
          <a
            href="/"
            className="-m-1.5 p-1.5"
            onClick={(e) => handleClick(e, "/")}
          >
            <span className="sr-only">AIOU</span>
            <Image
              className="h-16 w-auto"
              src="/logos/aiou.jpeg"
              alt="AIOU Logo"
              width={64}
              height={64}
            />
          </a>
        </div>

        {/* Mobile menu */}
        <div className={`lg:hidden ${mobileMenuOpen ? "" : "hidden"}`}>
          <div className="fixed inset-0 z-50" />
          <div className="fixed inset-y-0 right-0 z-50 w-full overflow-y-auto bg-white px-6 py-6 sm:max-w-sm sm:ring-1 sm:ring-gray-900/10">
            <div className="flex items-center justify-between">
              <div className="flex items-center gap-8">
                <Image
                  className="h-12 w-auto"
                  src="/logos/nacte.jpeg"
                  alt="NACTE Logo"
                  width={48}
                  height={48}
                />
                <Image
                  className="h-12 w-auto"
                  src="/logos/aiou.jpeg"
                  alt="AIOU Logo"
                  width={48}
                  height={48}
                />
              </div>
              <button
                type="button"
                className="-m-2.5 rounded-md p-2.5 text-gray-700"
                onClick={() => setMobileMenuOpen(false)}
              >
                <span className="sr-only">Close menu</span>
                <X className="h-6 w-6" aria-hidden="true" />
              </button>
            </div>
            <div className="mt-6 flow-root">
              <div className="-my-6 divide-y divide-gray-500/10">
                <div className="space-y-2 py-6">
                  {navigation.map((item) => (
                    <a
                      key={item.name}
                      href={item.href}
                      onClick={(e) => handleClick(e, item.href)}
                      className={getMobileNavItemClass(item.href)}
                    >
                      {item.name}
                    </a>
                  ))}
                </div>
              </div>
            </div>
          </div>
        </div>
      </nav>
    </header>
  );
};

export default Navbar;
