import { useState, useEffect } from 'react';
import { Sun, Moon, Monitor, Check } from 'lucide-react';
import * as DropdownMenu from '@radix-ui/react-dropdown-menu';

type Theme = 'light' | 'dark' | 'system';

const ThemeToggle = () => {
  const [theme, setTheme] = useState<Theme>('system');
  const [mounted, setMounted] = useState(false);

  useEffect(() => {
    setMounted(true);
    const savedTheme = localStorage.getItem('theme') as Theme || 'system';
    setTheme(savedTheme);
  }, []);

  useEffect(() => {
    if (!mounted) return;

    const root = document.documentElement;
    const systemTheme = window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
    const effectiveTheme = theme === 'system' ? systemTheme : theme;

    root.classList.remove('light', 'dark');
    root.classList.add(effectiveTheme);
    localStorage.setItem('theme', theme);
  }, [theme, mounted]);

  if (!mounted) return null;

  const currentTheme = theme === 'system'
    ? window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light'
    : theme;

  return (
    <DropdownMenu.Root>
      <DropdownMenu.Trigger asChild>
        <button 
          className="p-2 rounded-lg hover:bg-gray-100 text-gray-600 hover:text-blue-600"
          aria-label={`Change theme, current theme: ${theme}`}
        >
          {theme === 'system' ? (
            <Monitor size={20} aria-hidden="true" />
          ) : currentTheme === 'dark' ? (
            <Moon size={20} aria-hidden="true" />
          ) : (
            <Sun size={20} aria-hidden="true" />
          )}
        </button>
      </DropdownMenu.Trigger>

      <DropdownMenu.Portal>
        <DropdownMenu.Content 
          className="min-w-[150px] bg-white rounded-lg shadow-lg p-1 text-gray-600 border border-gray-200"
          sideOffset={5}
          aria-label="Theme options"
        >
          <DropdownMenu.Item
            onClick={() => setTheme('light')}
            className="flex items-center gap-2 px-2 py-1.5 text-sm outline-none cursor-default hover:bg-gray-50 hover:text-blue-600 rounded select-none"
            role="menuitemradio"
            aria-checked={theme === 'light'}
          >
            <Sun size={16} aria-hidden="true" />
            <span className="flex-grow">Light</span>
            {theme === 'light' && <Check size={16} className="text-blue-600" aria-hidden="true" />}
          </DropdownMenu.Item>
          <DropdownMenu.Item
            onClick={() => setTheme('dark')}
            className="flex items-center gap-2 px-2 py-1.5 text-sm outline-none cursor-default hover:bg-gray-50 hover:text-blue-600 rounded select-none"
            role="menuitemradio"
            aria-checked={theme === 'dark'}
          >
            <Moon size={16} aria-hidden="true" />
            <span className="flex-grow">Dark</span>
            {theme === 'dark' && <Check size={16} className="text-blue-600" aria-hidden="true" />}
          </DropdownMenu.Item>
          <DropdownMenu.Item
            onClick={() => setTheme('system')}
            className="flex items-center gap-2 px-2 py-1.5 text-sm outline-none cursor-default hover:bg-gray-50 hover:text-blue-600 rounded select-none"
            role="menuitemradio"
            aria-checked={theme === 'system'}
          >
            <Monitor size={16} aria-hidden="true" />
            <span className="flex-grow">System</span>
            {theme === 'system' && <Check size={16} className="text-blue-600" aria-hidden="true" />}
          </DropdownMenu.Item>
        </DropdownMenu.Content>
      </DropdownMenu.Portal>
    </DropdownMenu.Root>
  );
};

export default ThemeToggle;